Index: /CKEditor/branches/features/toolbargroup/_source/plugins/toolbar/plugin.js
===================================================================
--- /CKEditor/branches/features/toolbargroup/_source/plugins/toolbar/plugin.js	(revision 6689)
+++ /CKEditor/branches/features/toolbargroup/_source/plugins/toolbar/plugin.js	(revision 6690)
@@ -166,4 +166,8 @@
 						if ( groupCycling )
 						{
+							// Arrow cannot be used to navigate through group-less items.
+							if ( !( item.parent instanceof group ) )
+								return false;
+
 							while( !next )
 							{
@@ -171,5 +175,5 @@
 								if ( !next )
 								{
-									// Cyrcling inside the group when button group existed.
+									// Circling inside the group when button group existed.
 									if ( item.parent instanceof group )
 										next = item.parent;
@@ -280,5 +284,5 @@
 										itemName = buttons[ j ];
 
 									// Ignore separater in group mode.
 									if ( itemName == '-' && !isGroup )
 										button = CKEDITOR.ui.separator;
@@ -314,4 +318,5 @@
 								{
 									output.push( '</span>' );
+									i != row.length -1 && CKEDITOR.ui.separator.render( editor, output );
 									groupStarted = 0;
 								}
@@ -280,5 +284,5 @@
 										itemName = buttons[ j ];
 
-									// Ignore separater in group mode.
+									// Ignore separator in group mode.
 									if ( itemName == '-' && !isGroup )
 										button = CKEDITOR.ui.separator;
